# oidcrp
High level interface to the OIDC RP library

oidcrp represents the 4th layer in the
JWTConnect stack (cryptojwt, oidcmsg, oidcservice, oidcrp)

See the documentation at http://oidcrp.readthedocs.io/en/latest/ .

See sample RPs at https://github.com/openid/JWTConnect-Python-OidcRP/tree/master/chrp .  Has example configurations for Facebook, GitHub, Google, LinkedIn, Microsoft, Okta, Ping Federate, and Salesforce.
